import java.awt.print.PrinterException;
import java.awt.print.PrinterJob;
import java.io.File;
import java.io.IOException;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

import javax.print.PrintService;
import javax.print.PrintServiceLookup;

import org.apache.pdfbox.pdmodel.PDDocument;
import org.apache.pdfbox.pdmodel.PDPage;
import org.apache.pdfbox.pdmodel.PDResources;
import org.apache.pdfbox.pdmodel.font.PDFont;
import org.apache.pdfbox.pdmodel.font.PDSimpleFont;

public class PDFBoxTest {

	private static final String printerName = "HP LaserJet Professional P1606dn";

	public static void main(String[] args) throws IOException, PrinterException {
		PDFBoxTest.printPdf("c:/test2.pdf");
	}

	public static void printPdf(String fileName) throws IOException, PrinterException {
		PDDocument doc = PDDocument.load(new File(fileName));
		listFontsInDoc(doc);
		PrinterJob pjob = getPrinterJob();
		pjob.setJobName(fileName);
		pjob.setPageable(doc);
		pjob.print();

	}

	public static PrinterJob getPrinterJob() throws PrinterException {
		PrintService[] services = PrintServiceLookup.lookupPrintServices(null, null);
		PrinterJob pjob = PrinterJob.getPrinterJob();
		if (services != null)
			for (int i = 0; i < services.length; i++) {
				String svcName = services[i].getName();
				if (svcName.contains(printerName)) {
					pjob.setPrintService(services[i]);
					break;
				}
			}
		return pjob;
	}

	private static void listFontsInDoc(PDDocument document) {
		List<?> pages = document.getDocumentCatalog().getAllPages();
		for (int i = 0; i < pages.size(); i++) {
			PDPage page = (PDPage) pages.get(i);

			PDResources resource = page.getResources();
			Map<String, PDFont> fonts = resource.getFonts();

			Iterator<String> keyIterator = fonts.keySet().iterator();
			Object key = null;
			PDSimpleFont font = null;
			// PDFontDescriptor desc = null;
			System.out.println("Fonts list in page - " + i);
			while (keyIterator.hasNext()) {
				key = keyIterator.next();
				font = (PDSimpleFont) fonts.get(key);
				System.out.println(key.toString() + " - " + font.getFontDescriptor().getFontName());
			}
		}
	}
}
